@@ -1,7 +1,7 @@
 ManagePolygons <- function(ply=NULL, encoding=getOption("encoding"),
                            parent=NULL) {
-  # A GUI for managing and manipulating polygons that is based
-  # on the gpclib package.
+  # A GUI for managing and manipulating polygons;
+  # based on the gpclib package.
 
   # Additional functions (subroutines)
 
@@ -198,7 +198,7 @@ ManagePolygons <- function(ply=NULL, encoding=getOption("encoding"),
     if (length(idxs) != 0)
       cur.name <- old.names[idxs[1]]
 
-    new.names <- Rename(old.names, cur.name, "Rename Polygon", tt)
+    new.names <- Rename(old.names, cur.name, "Rename Polygons", tt)
 
     if (!is.null(new.names) && length(new.names) == length(old.names)) {
       if (identical(new.names, old.names))
@@ -278,11 +278,10 @@ ManagePolygons <- function(ply=NULL, encoding=getOption("encoding"),
           all.idxs[c(i - 1, i)] <- all.idxs[c(i, i - 1)]
       }
       ply <<- ply[all.idxs]
-      if (length(new.idxs) == 0) {
+      if (length(new.idxs) == 0)
         new.idxs <- 1
-      } else {
+      else
         new.idxs <- (1:n)[all.idxs %in% new.idxs]
-      }
     } else if (type == "forward") {
       n <- length(ply)
       new.idxs <- idxs
@@ -293,16 +292,14 @@ ManagePolygons <- function(ply=NULL, encoding=getOption("encoding"),
       }
       all.idxs <- na.omit(all.idxs)
       ply <<- ply[all.idxs]
-      if (length(new.idxs) == 0) {
+      if (length(new.idxs) == 0)
         new.idxs <- n
-      } else {
+      else
         new.idxs <- (1:n)[all.idxs %in% new.idxs]
-      }
     }
-    for (i in seq(along=ply)) {
+    for (i in seq(along=ply))
       tclvalue(list.var) <- tcl("lreplace", tclvalue(list.var),
                                 i - 1, i - 1, names(ply)[i])
-    }
     tkselection.clear(frame1.lst, 0, "end")
     for (i in new.idxs - 1)
       tkselection.set(frame1.lst, i)
@@ -473,7 +470,7 @@ ManagePolygons <- function(ply=NULL, encoding=getOption("encoding"),
 
   tkconfigure(tt, menu=top.menu)
 
-  # Frame 0 contains ok and cancel buttons, and size grip
+  # Frame 0, ok and cancel buttons, and size grip
 
   frame0 <- ttkframe(tt, relief="flat")
 
@@ -519,7 +516,7 @@ ManagePolygons <- function(ply=NULL, encoding=getOption("encoding"),
          pady=c(7, 0), padx=c(0, 6))
 
   n <- length(ply)
-  if (n > 1)
+  if (n > 0)
     tkselection.set(frame1.lst, n - 1)
 
   tkbind(frame1.lst, "<ButtonRelease-1>", PlotPolygon)
